#! /opt/ruby/bin/ruby -w
# @(#) $Id: example.rb 1.1 Mon, 02 May 2005 18:59:35 +0200 mxp $

# RubyMalaga usage example

require 'malaga'
require 'pp'

# Create a MalagaGrammar object.  "german.pro" refers to the example
# German syntax distributed with Malaga; you may have to adjust the
# path to the project file.
g = MalagaGrammar.new('/opt/malaga/grammars/german/german.pro')

# Get the name of the project file
puts "Project file: #{g.grammar}"
puts

# Get the informative text defined in the project file
puts "Grammar info: \n#{g.info}"
puts

# Set an option
g.option("sort-records", "alphabetic")

# Get the options that we've set
puts g.options.inspect
puts

# Analyze a word morphologically
a = g.analyze("gibt")

# This grammar returns its analysis as a record.  Print the entries of
# this record for the first (and in this case only) analysis result.
puts "First analysis result for '#{a[0].surface}':"
pp(a[0].category)

# Retrieving a specific category value
puts "The base form is: #{a[0].category['base']}" # or use: a[0]['base']
puts

# Analyze a sentence syntactically
a = g.analyze_s("Andrea schreibt ein Buch.")

puts "Number of analyses for '#{a[0].surface}': #{a.size}"
puts "Analysis where 'Andrea' is the subject:"

a.each {|analysis|
  subj = (analysis['arguments'].select {|arg| arg['function'] == :subject})[0]
  pp analysis.category if subj['surf'] == 'Andrea'
}
